@@ -21,8 +21,8 @@
 ;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 ;; USA
 
-;; Package-Version: 20260216.52
-;; Package-Revision: cee2cadc5fbe
+;; Package-Version: 20260217.1416
+;; Package-Revision: 28b5bbf1a026
 ;; Author: Adrien Brochard
 ;; Keywords: kubernetes k8s tools processes
 ;; URL: https://github.com/abrochard/kubel
@@ -586,7 +586,7 @@ READONLY if non-nil, buffer will be in `view-mode'."
                   :file-handler t
                   :stderr (get-buffer-create error-buffer)
                   :command cmd)
-    (pop-to-buffer buffer-name)
+    (pop-to-buffer-same-window buffer-name)
     (if readonly
         (with-current-buffer buffer-name
           (view-mode)))))
@@ -1225,8 +1225,12 @@ RESET is to be called if the search is nil after the first attempt."
 (defun kubel-show-process-buffer ()
   "Show the kubel-process-buffer."
   (interactive)
-  (pop-to-buffer kubel--process-buffer)
-  (special-mode))
+  (with-current-buffer (get-buffer-create kubel--process-buffer)
+    (special-mode))
+  (select-window
+   (display-buffer kubel--process-buffer
+                   '(display-buffer-below-selected
+                     (window-height . 0.4)))))
 
 (defun kubel-mark-item ()
   "Mark or unmark the item under cursor."
